<?php

    /**
     * Description of widget_castlist
     *
     * @author Rika.K
     */
    class CP5_Widget_ScheduleSlider extends CP5_Widget {

        function __construct() {
            $this->widget_name = '出勤スライダー';
            $this->widget_default_label = '出勤スライダー';

            add_action( 'wp_enqueue_scripts', array( $this, 'widget_castslider_enqueue_scripts' ), 10 );

            parent::__construct();
        }

        protected function option_param() {
            return array(
                '3size' => '身長・スリーサイズを表示',
                'icon' => 'アイコンを表示',
            );
        }

        protected function get_wp_query( $args, $instance ) {

            $schedule_attr = array();

            //先にスケジュールデータを確保しておく
            $schData = CP5_Schedule::get_scheduleByTime( $this->startTime, $this->endTime, '', '', false );

            if ( empty( $schData ) ) {
                $schData = array();
            }

            if ( isset( $instance['page_limit'] ) ) {
                $schedule_attr['posts_per_page'] = $instance['page_limit'];
            }

            $this->wpq = CP5_Schedule::CP5_get_cast_schedule_WP_Query( $this->startTime, $this->endTime, $schedule_attr );

            $this->gidArr = $schData;
        }

        /**
         * ウィジェット本体
         * @param type $args
         * @param type $instance
         */
        public function widget( $args, $instance ) {

            $instance = $this->instance_update_default( $instance );

            //現在時刻
            $ts = time();

            $this->startTime = CP5::get_switchTime( 'U' ) - CP5::get_gmt_offset();
            $this->endTime = $this->startTime + DAY_IN_SECONDS;

            echo $args['before_widget'];

            echo $args['before_title'] . $instance['title'] . $args['after_title'];

            //WP_Query実行
            $this->get_wp_query( $args, $instance );

            if ( class_exists( 'CP5_Machihime' ) ) {
                $machihimeObj = new CP5_Machihime();
                $machihimeObj->load_all_status( $this->gidArr );
            }

            if ( $this->wpq->have_posts() ):
                echo '<div id="carousel-container-' . $this->id . '" class="owl-carousel owl-theme">';

                while ( $this->wpq->have_posts() ) : $this->wpq->the_post();

                    $castID = get_the_ID();

                    if ( class_exists( 'CP5_Machihime' ) ) {
                        $thisState = $machihimeObj->get_stateSingle( $castID );
                    }


                    $schObj = $thisState->sch[0];
                    $timeFormat = get_option( 'time_format' );
                    $inTime = date( $timeFormat, CP5::add_gmt_offset( cp5_ms2sec( $schObj->in_time ) ) );

                    $outTime = date( $timeFormat, CP5::add_gmt_offset( cp5_ms2sec( $schObj->out_time ) ) );

                    //店舗IDを取得
                    $shop_id = (is_main_site()) ? get_post_meta( $castID, CP5::SyncShopID, true ) : get_current_blog_id();
                    //ラスト表記の確認
                    $outTime = cp5_is_outTimeLast( $shop_id, $schObj, $outTime );
                    ?>
                    <div class="swiper-slide text-center" data-girlid="<?php echo $castID; ?>">

                        <a href="<?php echo get_permalink(); ?>" data-mh="cast-list">
                            <div class="cast-frame">
                                <div class="cast-image">
                                    <?php echo cp5_get_cast_image( $castID, 'cast-s' ); ?>
                                </div>
                                <div class="cast-section text">
                                    <div class="cast-name"><?php echo cp5_get_cast_name( $castID ); ?></div>
                                    <?php if ( $instance['3size'] === 'on' ) { ?>
                                        <div class="cast-size"><?php echo cp5_get_cast_size( $castID ); ?></div>
                                    <?php } ?>
                                    <div class="cast-schedule-time">
                                        <?php echo sprintf( '<i class="fa fa-clock-o"></i> <span class="num">%s</span> - <span class="num">%s</span>', $inTime, $outTime ); ?>
                                    </div>
                                    <?php if ( $instance['icon'] === 'on' ) { ?>
                                        <div class="cast-icon"><?php echo cp5_get_cast_icons( $castID ); ?></div>
                                    <?php } ?>

                                    <?php if ( $schObj->free_text ) { ?>
                                        <div class="cast-schedule-comment free-text">
                                            <?php echo sprintf( '<p>%s</p>', $schObj->free_text ); ?>
                                        </div>
                                    <?php } ?>
                                    <?php if ( class_exists( 'CP5_Machihime' ) ) { ?>
                                        <div class="cast-state-icon text-center">
                                            <?php $machihimeObj->echo_stateIcon( $thisState, 'div' ); ?>
                                        </div>
                                        <div class="cast-state-messege text-center">
                                            <?php $machihimeObj->echo_stateMessage( $thisState, true ); ?>
                                        </div>
                                        <div class="marquee"><p><?php echo $thisState->comment; ?></p></div>
                                    <?php } ?>
                                </div>
                            </div>
                        </a>
                    </div>
                    <?php
                endwhile;
                // 投稿データをリセット
                wp_reset_postdata();
                ?>

                <?php echo '</div>'; ?>

                <?php
            else:
                echo '<div class="text-center no-data">' . __( 'No results found.', 'castpro5' ) . '</div>';
            endif;

            echo $args['after_widget'];
        }

        /**
         * ウィジェットオプションフォーム
         * @param type $instance
         */
        public function form( $instance ) {

            $instance = wp_parse_args( ( array ) $instance, array(
                'title' => '',
                'slidespeed' => 500,
                'slidenumber' => 1,
                'slidenumber_mobile' => 1,
                'effect' => '',
                'autoheight' => '',
                'loop' => '',
                'pagination' => '',
                'navigation' => '',
                'page_limit' => 10,
                '3size' => '',
                'icon' => '',
                    )
            );   //クエリーとデフォルト値のマージ（合併）
            //オプション項目
            $options = $this->option_param();
            ?>
            <p>
                <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'castpro5' ); ?></label>
                <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>" />
            </p>

            <p>
                <label for="<?php echo $this->get_field_id( 'slidespeed' ); ?>"><?php _e( 'Slide of speed:', 'castpro5' ); ?></label>
                <input class="widefat" id="<?php echo $this->get_field_id( 'slidespeed' ); ?>" name="<?php echo $this->get_field_name( 'slidespeed' ); ?>" type="number" value="<?php echo esc_attr( $instance['slidespeed'] ); ?>" />
            </p>

            <p>
                <label for="<?php echo $this->get_field_id( 'slidenumber' ); ?>"><?php _e( 'Number of slides:', 'castpro5' ); ?></label><br>
                <input id="<?php echo $this->get_field_id( 'slidenumber' ); ?>" name="<?php echo $this->get_field_name( 'slidenumber' ); ?>" type="range" class="column-slider" value="<?php echo esc_attr( $instance['slidenumber'] ); ?>" step="1" min="1" max="10" /><span class="column-slider-val"><?php echo esc_attr( $instance['slidenumber'] ); ?></span>
            </p>

            <p>
                <label for="<?php echo $this->get_field_id( 'slidenumber-mobile' ); ?>"><?php _e( 'Number of slides (mobile):', 'castpro5' ); ?></label><br>
                <input id="<?php echo $this->get_field_id( 'slidenumber-mobile' ); ?>" name="<?php echo $this->get_field_name( 'slidenumber_mobile' ); ?>" type="range" class="column-slider" value="<?php echo esc_attr( $instance['slidenumber_mobile'] ); ?>" step="1" min="1" max="10" /><span class="column-slider-val"><?php echo esc_attr( $instance['slidenumber_mobile'] ); ?></span>
            </p>

            <p>
                <label for="<?php echo $this->get_field_id( 'effect' ); ?>"><?php _e( 'Slider Effect:', 'castpro5' ); ?></label><br>

                <select name="<?php echo $this->get_field_name( 'effect' ); ?>" id="<?php echo $this->get_field_id( 'effect' ); ?>">
                    <option value="slide" <?php selected( 'slide', $instance['effect'] ); ?>><?php _e( 'Slide', 'castpro5' ); ?></option>
                    <option value="fade" <?php selected( 'fade', $instance['effect'] ); ?>><?php _e( 'Fade', 'castpro5' ); ?></option>
                    <?php /*      <option value="cube" <?php selected( 'cube', $instance['effect'] ); ?>><?php _e( 'Cube', 'castpro5' ); ?></option>
                      <option value="coverflow" <?php selected( 'coverflow', $instance['effect'] ); ?>><?php _e( 'Coverflow', 'castpro5' ); ?></option>
                      <option value="flip" <?php selected( 'flip', $instance['effect'] ); ?>><?php _e( 'Flip', 'castpro5' ); ?></option> */ ?>
                </select><br>
                <span class="description customize-control-description">※「フェード」は1枚表示の場合のみ有効</span><br>
            </p>

            <p>
                <input class="checkbox" id="<?php echo $this->get_field_id( 'autoheight' ); ?>" name="<?php echo $this->get_field_name( 'autoheight' ); ?>" type="checkbox" <?php checked( 'on', $instance['autoheight'] ); ?>> <label for="<?php echo $this->get_field_id( 'autoheight' ); ?>"><?php _e( 'To enable the automatic adjustment of height', 'castpro5' ); ?></label><br>

                <input class="checkbox" id="<?php echo $this->get_field_id( 'loop' ); ?>" name="<?php echo $this->get_field_name( 'loop' ); ?>" type="checkbox" <?php checked( 'on', $instance['loop'] ); ?>> <label for="<?php echo $this->get_field_id( 'loop' ); ?>"><?php _e( 'Enable the loop', 'castpro5' ); ?></label><br>

                <input class="checkbox" id="<?php echo $this->get_field_id( 'pagination' ); ?>" name="<?php echo $this->get_field_name( 'pagination' ); ?>" type="checkbox" <?php checked( 'on', $instance['pagination'] ); ?>> <label for="<?php echo $this->get_field_id( 'pagination' ); ?>"><?php _e( 'Displays the pagination', 'castpro5' ); ?></label><br>

                <input class="checkbox" id="<?php echo $this->get_field_id( 'navigation' ); ?>" name="<?php echo $this->get_field_name( 'navigation' ); ?>" type="checkbox" <?php checked( 'on', $instance['navigation'] ); ?>> <label for="<?php echo $this->get_field_id( 'navigation' ); ?>"><?php _e( 'Display the navigation', 'castpro5' ); ?></label><br>
            </p>

            <p>
                <label for="<?php echo $this->get_field_id( 'page-limit' ); ?>"><?php _e( 'Display number of people', 'castpro5' ); ?></label>
                <input class="tiny-text" id="<?php echo $this->get_field_id( 'page_limit' ); ?>" name="<?php echo $this->get_field_name( 'page_limit' ); ?>" type="number" value="<?php echo esc_attr( $instance['page_limit'] ); ?>" step="1" min="1" size="3" />
            </p>

            <p>
                <?php foreach ( $options as $key => $value ): ?>
                    <input class="widefat" id="<?php echo $this->get_field_id( $key ); ?>" name="<?php echo $this->get_field_name( $key ); ?>" type="checkbox" <?php checked( 'on', $instance[$key] ); ?>/><label for="<?php echo $this->get_field_id( $key ); ?>"><?php echo $value ?></label><br>
                <?php endforeach; ?>
            </p>
            <?php
        }

        function update( $new_instance, $old_instance ) {
            // ウィジェットの設定の更新処理を記述。主にセキュリティを考えたサニタイズ用

            $new_instance['title'] = strip_tags( $new_instance['title'] );    //不要なNULL、HTMLタグ、PHPソースコードを排除

            return $new_instance;
        }

        function widget_castslider_enqueue_scripts( $instance ) {

            wp_enqueue_style( 'owlcarousel', get_template_directory_uri() . '/lib/owlcarousel/assets/owl.carousel.min.css', array(), '2.2.0', 'all' );
            wp_enqueue_style( 'owlc-theme-default', get_template_directory_uri() . '/lib/owlcarousel/assets/owl.theme.default.min.css', array( 'owlcarousel' ), '2.2.0', 'all' );
            wp_enqueue_script( 'owlcarousel', get_template_directory_uri() . '/lib/owlcarousel/owl.carousel.min.js', array( 'jquery' ), '2.2.0', true );


            $this->startTime = CP5::get_switchTime( 'U' ) - CP5::get_gmt_offset();
            $this->endTime = $this->startTime + DAY_IN_SECONDS;


            $slider_options = get_option( $this->option_name );

            foreach ( ( array ) $slider_options as $slider_key => $slider_op ) {

                if ( !is_active_widget( false, $this->id_base . '-' . $slider_key, $this->id_base, true ) ) {

                    continue;
                }

                $slider_config = array();

                if ( isset( $slider_op['page_limit'] ) && $slider_op['page_limit'] ) {

                    $instance['page_limit'] = $slider_op['page_limit'];
                }

                //WP_Query実行
                $this->get_wp_query( '', $instance );

                //スピード
                if ( isset( $slider_op['slidespeed'] ) && $slider_op['slidespeed'] ) {
                    $slider_config['smartSpeed'] = ( int ) $slider_op['slidespeed'];
                }

                //ループ

                if ( isset( $slider_op['loop'] ) && ($this->wpq->post_count > ( int ) $slider_op['slidenumber'] ) ) {
                    $slider_config['responsive']['768']['loop'] = true;
                }

                if ( isset( $slider_op['loop'] ) && ($this->wpq->post_count > ( int ) $slider_op['slidenumber_mobile'] ) ) {
                    $slider_config['responsive']['0']['loop'] = true;
                }

                //エフェクト
                if ( isset( $slider_op['effect'] ) && $slider_op['effect'] === 'fade' ) {
                    $slider_config['animateOut'] = 'fadeOut';
                }

                //スライド数
                if ( isset( $slider_op['slidenumber'] ) && $slider_op['slidenumber'] ) {
                    $slider_config['items'] = ( int ) $slider_op['slidenumber'];
                }

                //スライドスマートフォン
                if ( isset( $slider_op['slidenumber_mobile'] ) && $slider_op['slidenumber_mobile'] ) {
                    $slider_config['responsive']['768']['items'] = ( int ) $slider_op['slidenumber'];
                    $slider_config['responsive']['0']['items'] = ( int ) $slider_op['slidenumber_mobile'];
                }

                //高さを自動調整
                if ( isset( $slider_op['autoheight'] ) && $slider_op['autoheight'] === 'on' ) {
                    $slider_config['autoHeight'] = true;
                }

                //ページネーション
                if ( isset( $slider_op['pagination'] ) && $slider_op['pagination'] === 'on' ) {
                    $slider_config['dots'] = true;
                } else {
                    $slider_config['dots'] = false;
                }

                //ナビゲーション
                if ( isset( $slider_op['navigation'] ) && $slider_op['navigation'] == 'on' ) {
                    $slider_config['nav'] = 'true';
                    $slider_config['navClass'] = array( 'slide-prev', 'slide-next' );
                    $slider_config['navText'] = array( '', '' );
                }

                wp_reset_postdata();

                wp_add_inline_script( 'owlcarousel', "
                      $(function() {
             var owl" . $this->id_base . $this->number . " = $('#carousel-container-" . $this->id_base . "-" . $this->number . "');
             owl" . $this->id_base . $this->number . ".owlCarousel(" . json_encode( $slider_config ) . ");
        });
     " );
            }
        }

    }

    /*
     * Wordpressへ登録
     */

    add_action( 'widgets_init', function() {
        return register_widget( 'CP5_Widget_ScheduleSlider' );
    } );
    